import _ from 'lodash'
import { clsx } from '@/lib/utils'

export const Value = ({ value, borderless } = {}) => {
    return value === undefined ? (
        <em>undefined</em>
    ) : value === null ? (
        <em>null</em>
    ) : value === true ? (
        <em>true</em>
    ) : value === false ? (
        <em>false</em>
    ) : typeof value === 'string' && value.trim().length === 0 ? (
        <em>Empty string</em>
    ) : !value ? (
        value
    ) : Array.isArray(value) ? (
        <ValueArray value={value} borderless={borderless} />
    ) : typeof value === 'object' ? (
        <ValueObject value={value} borderless={borderless} />
    ) : (
        value
    )
}

export const ValueArray = ({ value, borderless }) => {
    return value.length === 0 ? (
        <em>Empty array</em>
    ) : (
        <div class={clsx('compound-value array', borderless && 'borderless')}>
            {value.map(item => (
                <div class="item">
                    <Value value={item} borderless={borderless} />
                </div>
            ))}
        </div>
    )
}

export const ValueObject = ({ value, borderless }) => {
    return (
        <div class={clsx('compound-value object', borderless && 'borderless')}>
            {Object.entries(value).map(([k, v]) => (
                <>
                    <div title={k} class="key">
                        {_.startCase(k)}
                    </div>
                    <div class="value">
                        <Value value={v} borderless={borderless} />
                    </div>
                </>
            ))}
        </div>
    )
}
