import { EventEmitter } from 'events'
import type { Job } from './jobs'

const emitter = new EventEmitter()

export const OnJobAdded = {
    emit(job: Job) {
        emitter.emit('job:add', job)
    },
    addListener(cb: (job: Job) => void) {
        emitter.on('job:add', cb)
    },
    removeListener(cb: (job: Job) => void) {
        emitter.off('job:add', cb)
    },
}

export const OnJobCompleted = {
    emit(job: Job) {
        emitter.emit('job:completed', job)
    },
    addListener(cb: (job: Job) => void) {
        emitter.on('job:completed', cb)
    },
    removeListener(cb: (job: Job) => void) {
        emitter.off('job:completed', cb)
    },
}

export const OnJobStarted = {
    emit(job: Job) {
        emitter.emit('job:started', job)
    },
    addListener(cb: (job: Job) => void) {
        emitter.on('job:started', cb)
    },
    removeListener(cb: (job: Job) => void) {
        emitter.off('job:started', cb)
    },
}

export const OnJobLog = {
    emit(uuid: string, line: string) {
        emitter.emit(`job:log:${uuid}`, line)
    },
    addListener(uuid: string, cb: (line: string) => void) {
        emitter.on(`job:log:${uuid}`, cb)
    },
    removeListener(uuid: string, cb: (line: string) => void) {
        emitter.off(`job:log:${uuid}`, cb)
    },
}
