import { OnJobLog } from '@/events'
import { getJobLogs, getLatestJobByName } from '@/jobs'
import { JsonResponse, JsonStreamResponse, createUrlQuery } from '@/lib/utils'
import { debug } from '@/logger'
import type { APIRoute } from 'astro'

export const GET: APIRoute = async ({ params: { name }, url, redirect }) => {
    const latestJob = await getLatestJobByName(name!)
    if (!latestJob) {
        return new Response('No jobs yet for this deploy', { status: 404 })
    }

    debug(latestJob)

    const rawLogs = await getJobLogs(latestJob.uuid)

    const format = url.searchParams.get('format')
    switch (format) {
        case 'raw':
            return new Response(rawLogs)
        case 'json':
            return new JsonResponse(rawLogs.trim().split('\n'))
        case 'sse':
            return new JsonStreamResponse(sendData => {
                const jobLog = (content: string) => sendData({ type: 'log', content })

                debug('[SSE] Registering job log client')
                OnJobLog.addListener(latestJob.uuid, jobLog)

                return () => {
                    // cancel
                    OnJobLog.removeListener(latestJob.uuid, jobLog)
                    debug('[SSE] Un-registered job log client')
                }
            })
        default:
            return redirect(createUrlQuery('/error', { message: `Invalid format "${format}"` }))
    }
}
